%define upstream_name    Math-PlanePath
%define upstream_version 129

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 3

Summary:    Mathematical paths through the 2-D plane
License:    GPLv1+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Math/%{upstream_name}-%{upstream_version}.tar.gz
BuildArch:  noarch

BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(List::Util)
BuildRequires: perl(Math::Libm)
BuildRequires: perl(Test)
BuildRequires: perl(constant) >= 1.20.0
BuildRequires: perl(constant::defer) >= 5.0.0
BuildRequires: perl-devel
Obsoletes:  perl-Math-PlanePath < 120.0.0-2

%description
This is the base class for some mathematical paths which map an integer
position '$n' to and from coordinates '$x,$y' in the 2D plane.

The current classes include the following. The intention is that any
'Math::PlanePath::Something' is a PlanePath, and supporting base classes or
related things are further down like 'Math::PlanePath::Base::Xyzzy'.

    SquareSpiral           four-sided spiral
    PyramidSpiral          square base pyramid
    TriangleSpiral         equilateral triangle spiral
    TriangleSpiralSkewed   equilateral skewed for compactness
    DiamondSpiral          four-sided spiral, looping faster
    PentSpiral             five-sided spiral
    PentSpiralSkewed       five-sided spiral, compact
    HexSpiral              six-sided spiral
    HexSpiralSkewed        six-sided spiral skewed for compactness
    HeptSpiralSkewed       seven-sided spiral, compact
    AnvilSpiral            anvil shape
    OctagramSpiral         eight pointed star
    KnightSpiral           an infinite knight's tour
    CretanLabyrinth        7-circuit extended infinitely

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc COPYING Changes META.json META.yml MYMETA.yml SIGNATURE examples
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Fri Jun 27 2025 umeabot <umeabot> 129.0.0-3.mga10
+ Revision: 2206845
- Mageia 10 Mass Rebuild

* Mon Mar 21 2022 umeabot <umeabot> 129.0.0-2.mga9
+ Revision: 1814097
- Mageia 9 Mass Rebuild

* Thu Feb 25 2021 tv <tv> 129.0.0-1.mga9
+ Revision: 1691405
- update to 129

* Mon Sep 28 2020 tv <tv> 128.0.0-1.mga8
+ Revision: 1630861
- update to 128

* Sat Feb 15 2020 umeabot <umeabot> 127.0.0-2.mga8
+ Revision: 1528654
- Mageia 8 Mass Rebuild

* Sun Aug 25 2019 tv <tv> 127.0.0-1.mga8
+ Revision: 1432101
- update to 127

* Tue Mar 12 2019 tv <tv> 126.0.0-3.mga7
+ Revision: 1374765
- fix summary

* Thu Sep 20 2018 umeabot <umeabot> 126.0.0-2.mga7
+ Revision: 1284758
- Mageia 7 Mass Rebuild

* Wed Mar 07 2018 shlomif <shlomif> 126.0.0-1.mga7
+ Revision: 1207227
- update to 126

* Sun Dec 10 2017 shlomif <shlomif> 125.0.0-1.mga7
+ Revision: 1182052
- update to 125

* Tue Oct 03 2017 tv <tv> 124.0.0-2.mga7
+ Revision: 1165388
- rebuild with fixed rpm for missing autodeps

* Wed Sep 20 2017 sander85 <sander85> 124.0.0-1.mga7
+ Revision: 1156100
- update to 124

* Fri Sep 15 2017 tv <tv> 123.0.0-1.mga7
+ Revision: 1154020
- fix SRPM creation due to doble noarch tag

* Sun May 08 2016 shlomif <shlomif> 123.0.0-1.mga6
+ Revision: 1010675
- update to 123

* Mon Jan 04 2016 shlomif <shlomif> 122.0.0-1.mga6
+ Revision: 919623
- New version

* Fri Oct 16 2015 tv <tv> 121.0.0-2.mga6
+ Revision: 892100
- make it noarch thus fixing empty debuginfo

* Wed Oct 14 2015 sander85 <sander85> 121.0.0-1.mga6
+ Revision: 891413
- update to 121

* Sun Aug 23 2015 sander85 <sander85> 120.0.0-1.mga6
+ Revision: 868504
- update to 120

* Thu Jun 25 2015 shlomif <shlomif> 119.0.0-1.mga6
+ Revision: 843289
- update to 119

* Sat Oct 18 2014 umeabot <umeabot> 116.0.0-4.mga5
+ Revision: 788133
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 116.0.0-3.mga5
+ Revision: 745975
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 116.0.0-2.mga5
+ Revision: 685371
- Mageia 5 Mass Rebuild

* Sat Jun 14 2014 sander85 <sander85> 116.0.0-1.mga5
+ Revision: 636186
- update to 116

* Tue Apr 15 2014 jquelin <jquelin> 115.0.0-1.mga5
+ Revision: 614910
- update to 115

* Mon Feb 10 2014 jquelin <jquelin> 114.0.0-1.mga5
+ Revision: 588489
- update to 114

* Tue Feb 04 2014 shlomif <shlomif> 113.0.0-1.mga5
+ Revision: 581241
- update to 113

* Sat Oct 19 2013 umeabot <umeabot> 110.0.0-2.mga4
+ Revision: 533975
- Mageia 4 Mass Rebuild

* Sun Sep 08 2013 sander85 <sander85> 110.0.0-1.mga4
+ Revision: 475886
- update to 110

* Fri Aug 23 2013 sander85 <sander85> 109.0.0-1.mga4
+ Revision: 470257
- update to 109

* Sun Jul 21 2013 sander85 <sander85> 108.0.0-1.mga4
+ Revision: 457001
- update to 108

* Thu Jul 04 2013 shlomif <shlomif> 107.0.0-1.mga4
+ Revision: 450214
- update to 107

* Sat Jun 22 2013 shlomif <shlomif> 106.0.0-1.mga4
+ Revision: 445646
- New ver 106

* Wed Jun 19 2013 shlomif <shlomif> 105.0.0-1.mga4
+ Revision: 445048
- New version 105

* Sat Jun 01 2013 shlomif <shlomif> 104.0.0-1.mga4
+ Revision: 434048
- New version 104

* Sun Jan 13 2013 umeabot <umeabot> 95.0.0-2.mga3
+ Revision: 369639
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 03 2013 shlomif <shlomif> 95.0.0-1.mga3
+ Revision: 338093
- update to 95

* Thu Dec 13 2012 shlomif <shlomif> 94.0.0-1.mga3
+ Revision: 330247
- update to 94

* Tue Nov 06 2012 jquelin <jquelin> 92.0.0-1.mga3
+ Revision: 315165
- update to 92

* Wed Oct 24 2012 shlomif <shlomif> 91.0.0-1.mga3
+ Revision: 309563
- update to 91

* Mon Oct 15 2012 jquelin <jquelin> 90.0.0-1.mga3
+ Revision: 306176
- update to 90

* Wed Sep 26 2012 jquelin <jquelin> 89.0.0-1.mga3
+ Revision: 298053
- update to 89

* Fri Sep 07 2012 shlomif <shlomif> 88.0.0-1.mga3
+ Revision: 289226
- update to 88

* Thu Aug 16 2012 shlomif <shlomif> 86.0.0-1.mga3
+ Revision: 281553
- update to 86

* Mon Aug 06 2012 shlomif <shlomif> 84.0.0-1.mga3
+ Revision: 279446
- update to 84

* Sat Jul 28 2012 shlomif <shlomif> 83.0.0-1.mga3
+ Revision: 275403
- update to 83

* Thu Jul 12 2012 jquelin <jquelin> 80.0.0-1.mga3
+ Revision: 270295
- update to 80

* Tue Jul 03 2012 shlomif <shlomif> 79.0.0-1.mga3
+ Revision: 267079
- update to 79

* Fri Jun 08 2012 shlomif <shlomif> 77.0.0-1.mga3
+ Revision: 257898
- New version - 77.0

* Thu May 31 2012 shlomif <shlomif> 76.0.0-2.mga3
+ Revision: 252367
- License fix
- imported package perl-Math-PlanePath


* Thu May 31 2012 cpan2dist 76-1mga
- initial mageia release, generated with cpan2dist
